@@ -9,7 +9,7 @@ async fn main() {
     "rmw upnp test",
     port,
     duration,
-    Box::new(|gateway, ext_port, ip, port| {
+    Box::new(move |gateway, ext_port, ip| {
       println!(
         "upnp success: ( {}:{} -> {}:{} )",
         gateway, ext_port, ip, port
